@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
 our $DATE = '2015-01-09'; # DATE
-our $VERSION = '0.74'; # VERSION
+our $VERSION = '0.75'; # VERSION
 
 use 5.010001;
 use strict;
@@ -303,13 +303,14 @@ _
 );
 
 sub __default_env_name {
-    my ($prog, $subc) = @_;
-    for ($prog, $subc) {
-        next unless defined;
+    my ($prog) = @_;
+
+    for ($prog) {
+        $_ //= "PROG"; # shouldn't happen
         $_ = uc($_);
         s/[^A-Z0-9]+/_/g;
     }
-    $prog . (defined($subc) ? "_$subc" : "") . "_OPT";
+    "${prog}_OPT";
 }
 
 sub hook_before_read_config_file {}
@@ -490,8 +491,9 @@ sub do_completion {
             }
             # if subcommand name has not been supplied and we're at arg#0,
             # complete subcommand name
-            if ($self->subcommands && $r->{subcommand_name_from} ne '--cmd' &&
-                    $args{type} eq 'arg' && $args{argpos}==0) {
+            if ($self->subcommands &&
+                    ($r->{subcommand_name_from}//'') ne '--cmd' &&
+                        $args{type} eq 'arg' && $args{argpos}==0) {
                 require Complete::Util;
                 return Complete::Util::complete_array_elem(
                     array => [keys %{ $self->list_subcommands }],
@@ -1103,7 +1105,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.74 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-01-09.
+This document describes version 0.75 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-01-09.
 
 =head1 DESCRIPTION
 
